==> huaweicloudsdkkafka-3.1.98-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/create_message_diagnosis_task_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateMessageDiagnosisTaskResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'report_id': 'str'
    }

    attribute_map = {
        'report_id': 'report_id'
    }

    def __init__(self, report_id=None):
        """CreateMessageDiagnosisTaskResponse

        The model defined in huaweicloud sdk

        :param report_id: 诊断报告id。
        :type report_id: str
        """
        
        super(CreateMessageDiagnosisTaskResponse, self).__init__()

        self._report_id = None
        self.discriminator = None

        if report_id is not None:
            self.report_id = report_id

    @property
    def report_id(self):
        """Gets the report_id of this CreateMessageDiagnosisTaskResponse.

        诊断报告id。

        :return: The report_id of this CreateMessageDiagnosisTaskResponse.
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this CreateMessageDiagnosisTaskResponse.

        诊断报告id。

        :param report_id: The report_id of this CreateMessageDiagnosisTaskResponse.
        :type report_id: str
        """
        self._report_id = report_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateMessageDiagnosisTaskResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.126-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/create_message_diagnosis_task_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateMessageDiagnosisTaskResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'report_id': 'str'
    }

    attribute_map = {
        'report_id': 'report_id'
    }

    def __init__(self, report_id=None):
        """CreateMessageDiagnosisTaskResponse

        The model defined in huaweicloud sdk

        :param report_id: 诊断报告ID。
        :type report_id: str
        """
        
        super(CreateMessageDiagnosisTaskResponse, self).__init__()

        self._report_id = None
        self.discriminator = None

        if report_id is not None:
            self.report_id = report_id

    @property
    def report_id(self):
        """Gets the report_id of this CreateMessageDiagnosisTaskResponse.

        诊断报告ID。

        :return: The report_id of this CreateMessageDiagnosisTaskResponse.
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this CreateMessageDiagnosisTaskResponse.

        诊断报告ID。

        :param report_id: The report_id of this CreateMessageDiagnosisTaskResponse.
        :type report_id: str
        """
        self._report_id = report_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateMessageDiagnosisTaskResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
